import { createRouter, createWebHistory, createWebHashHistory } from 'vue-router';
import { defineAsyncComponent } from 'vue';
import { useMainStore } from "@/stores/store";

const Home = defineAsyncComponent(() => import('@/views/Home.vue'));
const Login = defineAsyncComponent(() => import('@/views/Login.vue'));
const News = defineAsyncComponent(() => import('@/views/News.vue'));
const NewsDetail = defineAsyncComponent(() => import('@/views/NewsDetail.vue'));
const CourseList = defineAsyncComponent(() => import('@/views/CourseList.vue'));
const CourseDetail = defineAsyncComponent(() => import('@/views/CourseDetail.vue'));
const Craft = defineAsyncComponent(() => import('@/views/CollegeGroup/Craft.vue'));
const Generation = defineAsyncComponent(() => import('@/views/CollegeGroup/Generation.vue'));
const Future = defineAsyncComponent(() => import('@/views/CollegeGroup/Future.vue'));
const Repair = defineAsyncComponent(() => import('@/views/CollegeGroup/Repair.vue'));
const Teenager = defineAsyncComponent(() => import('@/views/CollegeGroup/Teenager.vue'));
const Cross = defineAsyncComponent(() => import('@/views/CollegeGroup/Cross.vue'));
// 學員頁面
const Dashboard = defineAsyncComponent(() => import('@/views/User/Dashboard.vue'));
const Profile = defineAsyncComponent(() => import('@/views/User/Profile.vue'));
const Passport = defineAsyncComponent(() => import('@/views/User/Passport.vue'));
const FavoriteClass = defineAsyncComponent(() => import('@/views/User/FavoriteClass.vue'));

const routes = [
  {
    path: '/',
    name: 'Home',
    component: Home,
  },
  {
    path: '/login',
    name: 'Login',
    component: Login,
  },
  // {
  //   path: '/user/profile',
  //   name: 'UserProfile',
  //   component: UserProfile,
  // },
  {
    path: '/user',
    component: Dashboard,
    meta: { requiresAuth: true }, // 需驗證登入權限
    children: [
      {
        path: 'profile',
        name: 'Profile',
        component: Profile,
      },
      {
        path: 'passport',
        name: 'Passport',
        component: Passport,
      },
      {
        path: 'favorite-class',
        name: 'FavoriteClass',
        component: FavoriteClass,
      },
    ],
  },
  {
    path: '/news',
    name: 'News',
    component: News,
  },
  {
    path: '/news/:id',
    name: 'NewsDetail',
    component: NewsDetail
  },
  {
    path: '/course-list',
    name: 'CourseList',
    component: CourseList
  },
  {
    path: '/course-detail/:id',
    name: 'CourseDetail',
    component: CourseDetail
  },
  {
    path: '/college-group/craft',
    name: 'Craft',
    component: Craft
  },
  {
    path: '/college-group/generation',
    name: 'Generation',
    component: Generation
  },
  {
    path: '/college-group/future',
    name: 'Future',
    component: Future
  },
  {
    path: '/college-group/repair',
    name: 'Repair',
    component: Repair
  },
  {
    path: '/college-group/teenager',
    name: 'Teenager',
    component: Teenager
  },
  {
    path: '/college-group/cross',
    name: 'Cross',
    component: Cross
  },
];

const router = createRouter({
  // history: createWebHashHistory(),
  history: createWebHistory(import.meta.env.BASE_URL),
  routes
});

// 檢查登入狀態
router.beforeEach((to, from, next) => {
  const store = useMainStore();
  store.checkToken();

  // 檢查目標路由是否需要驗證權限
  if (to.meta.requiresAuth) {
    const haveToken = store.loginState;
    if (haveToken) {
      next(); // 允許使用者訪問目標頁面
    } else {
      store.loginDialog = true; // 開啟登入視窗
      next('/'); // 若無 token 直接輸入網址前往時，將重定向至首頁
    }
  } else {
    // 如果目標路由不需要驗證權限，直接允許使用者訪問
    next();
  }
});

export default router;